;; Generated package description from marginalia.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "marginalia" "2.0" "Enrich existing commands with completion annotations" '((emacs "28.1") (compat "30")) :commit "c51fd9e4d4258543e0cd8dedda941789163bec5a" :authors '(("Omar Antolín Camarena" . "omar@matem.unam.mx") ("Daniel Mendler" . "mail@daniel-mendler.de")) :maintainer '(("Omar Antolín Camarena" . "omar@matem.unam.mx") ("Daniel Mendler" . "mail@daniel-mendler.de")) :keywords '("docs" "help" "matching" "completion") :url "https://github.com/minad/marginalia")
